==> magpie-data-0.5.7-sources.jar: io/openraven/magpie/data/aws/accounts/IamPolicy.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.accounts;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.iam.model.Policy;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = IamPolicy.TABLE_NAME)
public class IamPolicy extends AWSResource {
  protected static final String TABLE_NAME = "awsiampolicy";
  public static final String RESOURCE_TYPE = "AWS::IAM::Policy";

  public IamPolicy() {
    this.resourceType = RESOURCE_TYPE;

  }

  public IamPolicy(String accountId, String region, Policy policy) {
    this.arn = policy.arn();
    this.awsAccountId = accountId;
    this.awsRegion = region;
    this.resourceId = policy.policyId();
    this.resourceName = policy.policyName();
    this.resourceType = RESOURCE_TYPE;
    this.createdIso = policy.createDate();
    this.configuration = PayloadUtils.update(policy);
  }
}

==> magpie-data-0.11.2-sources.jar: io/openraven/magpie/data/aws/accounts/IamPolicy.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.accounts;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.iam.model.Policy;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = IamPolicy.TABLE_NAME)
public class IamPolicy extends AWSResource {
  protected static final String TABLE_NAME = "awsiampolicy";
  public static final String RESOURCE_TYPE = "AWS::IAM::Policy";

  public IamPolicy() {
    this.resourceType = RESOURCE_TYPE;

  }

  public IamPolicy(String accountId, String region, Policy policy) {
    this.arn = policy.arn();
    this.awsAccountId = accountId;
    this.awsRegion = region;
    this.resourceId = policy.policyId();
    this.resourceName = policy.policyName();
    this.resourceType = RESOURCE_TYPE;
    this.createdIso = policy.createDate();
    this.configuration = PayloadUtils.update(policy);
  }
}
